from setuptools import setup, find_packages

setup(
    name="greet-simple",
    version="0.1.0",
    description="A simple package for greeting people.",
    author="Your Name",
    author_email="your@email.com",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)